import {Component,
        Input, 
        Output,
        EventEmitter}           from '@angular/core';
import {FormBuilder, 
        FormGroup, 
        Validators}             from '@angular/forms';

import {BaseFilter}             from '../../base/index';
import {BaseFilterComponent}    from '../../base/index';
import {LogExceptionFilter}     from '../shared/data/log-exception.filter'; 
import {CustomValidators,
        BitMessage}             from '../../shared/index';
import {MessageService}         from '../../shared/service/message.service';
import {SessionSharedService}   from '../../shared/service/session-shared.service';

@Component({

    selector: 'exception-list-filter',
    template: "\n      <!-- Contenedor del filtro de búsqueda simple (siempre visible en pantalla) -->\n      <div class=\"panel panel-filtro\" [hidden]=\"!displayFilter\">\n          <div class=\"panel-heading\">\n              <i></i>&nbsp;&nbsp;&nbsp;Filtre de cerca\n          </div>\n          <form role=\"form\" [formGroup]=\"myForm\" (submit)=\"submit(myForm.value)\">\n              <div class=\"panel-body\">\n                  <div class=\"row\">\n                      <div class=\"col-xs-3\">\n                          <bit-input [(ngModel)]=\"filter.fecha\" [nombre]=\"'fecha'\" [control]=\"myForm.controls.fecha\" formControlName=\"fecha\" [tipo]=\"'date'\">&nbsp;&nbsp;Data</bit-input>\n                      </div> \n                      <div class=\"col-xs-3\">\n                          <bit-input [(ngModel)]=\"filter.desde\" [nombre]=\"'desde'\" [control]=\"myForm.controls.desde\" formControlName=\"desde\" [tipo]=\"'time'\">&nbsp;&nbsp;Des de</bit-input>\n                      </div>\n                      <div class=\"col-xs-3\">\n                          <bit-input [(ngModel)]=\"filter.hasta\" [nombre]=\"'hasta'\" [control]=\"myForm.controls.hasta\" formControlName=\"hasta\" [tipo]=\"'time'\">&nbsp;&nbsp;Fins a</bit-input>\n                      </div>\n                      <div class=\"col-xs-3\">\n                          <bit-input [(ngModel)]=\"filter.login\" [nombre]=\"'login'\" [ngModelOptions]=\"{standalone: true}\" [tipo]=\"'text'\">&nbsp;&nbsp;Login</bit-input>\n                      </div>\n                  </div>\n              </div>\n              <div class=\"panel-footer text-center\">\n                  <div class=\"btn-group\" role=\"group\">\n                      <button type=\"reset\" (click)=\"resetFilter()\" class=\"btn btn-default\">Neteja&nbsp;&nbsp;<span class=\"glyphicon glyphicon-erase\"></span></button>\n                  </div>\n                  <div class=\"btn-group\" role=\"group\">\n                      <button type=\"submit\" class=\"btn btn-success\">Cerca&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n                  </div>\n              </div>\n          </form>\n      </div>\n    "
})
export class ExceptionListFilterComponent extends BaseFilterComponent{
    filter: LogExceptionFilter;         // contiene el filtro de búsqueda. Será accedido directamente desde el padre

    constructor(
        private formBuilder: FormBuilder, 
        private messageService: MessageService,
        private sessionShared: SessionSharedService
    ) {
        super();
        //gestión del filtro
        this.filter = this.sessionShared.get("EXCEPTION_FILTER");
        if (this.filter === undefined) {
            this.filter = this.createNewFilter();
            this.filter.pagina = BaseFilter.PAGE;
            this.filter.resultados = BaseFilter.RESULTADOS_PAGE;
            this.sessionShared.set("EXCEPTION_FILTER", this.filter);
        }   
        //construimos el form         
        this.myForm = formBuilder.group({
            'fecha': [this.filter.fecha, [Validators.required, CustomValidators.dataValidator]],
            'desde': [this.filter.desde, [Validators.required]],//CustomValidators.timeValidator
            'hasta': [this.filter.hasta, [Validators.required]]
        });
    }

    /** Crea un nuevo filtro para realizar la búsqueda */
    createNewFilter(): LogExceptionFilter {
        return LogExceptionFilter.newObject(); 
    }

}
