import {Component,
        OnInit}           from '@angular/core';
import {FormBuilder,
        FormControl,
        Validators}       from '@angular/forms';
import {HQL}              from '../shared/data/hql';
import {PageStatus,
        BitMessage}       from '../../shared/index';
import {MessageService}   from '../../shared/service/message.service';
import {DeveloperService} from '../shared/service/developer.service';

/**
 * Clase que implementa la consulta de información con consultas HQL.
 */
@Component({

   selector: 'hql',
   template: "\n\n     <bit-header [noToolbar]=\"true\" [breadcrumb]=breadcrumb></bit-header>\n\n     <div class=\"panel panel-filtro\">\n       <div class=\"panel-heading\">\n         <i></i>&nbsp;&nbsp;&nbsp;HQL\n       </div>\n       <div class=\"panel-body\">\n           <form role=\"form\"> <!-- #f=\"ngForm\"-->\n           <div class=\"form-group\">\n             <div class=\"row\">\n                 <div class=\"col-xs-12\">\n                     <textarea class=\"form-control h-200\" id=\"hql\" name=\"hql\" [(ngModel)]=\"hql.hql\" [formControl]=\"hqlControl\"></textarea>\n                 </div>\n             </div>\n           </div>\n           </form>\n       </div>\n       <div class=\"panel-footer text-center\">\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" (click)=\"resetForm()\">Neteja&nbsp;&nbsp;<span class=\"glyphicon glyphicon-erase\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(false, false)\">Query SQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(true, false)\">Query HQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(true, true)\">Execute HQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-flash\"></span></button>\n         </div>\n       </div>\n     </div>\n\n     <div>\n           <pre [hidden]=\"!hql.resultado\">{{hql.resultado}}</pre> <!-- (!searchFinished || errorMessage)-->\n     </div>\n\n     <bit-footer [paginator]=\"false\" type=\"form\" [status]=\"status\" [messages]=\"messages\"></bit-footer>\n\n     <!--footer class=\"footer navbar-fixed-bottom\">\n         <ul class=\"navbar-right\">\n             <li>\n                 <span class=\"mensaje mensaje-informacion\" *ngIf=\"searchInitiated\"><i class=\"glyphicon glyphicon-info-sign\"></i>Introdueixi el HQL i premi \"Query\" o \"Execute\"</span>\n                 <span class=\"mensaje mensaje-informacion\" *ngIf=\"searching\">Cercant...</span>\n                 <span class=\"mensaje mensaje-error\" *ngIf=\"searchFinished && !errorMessage\"><i class=\"glyphicon glyphicon-alert\"></i>HQL executat</span>\n                 <span class=\"mensaje mensaje-error\" *ngIf=\"errorMessage\"><i class=\"glyphicon glyphicon-alert\"></i>{{errorMessage}}</span>\n             </li>\n         </ul>\n     </footer-->\n   "
})
export class HQLComponent implements OnInit {
   breadcrumb: any = [];
   status: PageStatus;
   messages: Map<PageStatus, string> = new Map<PageStatus, string>();
   hql: HQL;
   hqlControl: FormControl;

   /** Constructor de la clase. */
   constructor(
        private developerService: DeveloperService, 
        private formBuilder: FormBuilder,
        private messageService: MessageService
    ) {}
   
   /** Inicializa la ficha: define la validación. */
   ngOnInit(): any {
      this.init();
      this.hqlControl = this.formBuilder.control('', [Validators.required]);
      this.breadcrumb = [];
      this.breadcrumb.push({label: 'Developer'});
      this.breadcrumb.push({label: 'S/HQL'});
      this.messages.set(PageStatus.Init, "Introdueixi el S/HQL");
      this.messages.set(PageStatus.Searching, "Executant la consulta");
      this.messages.set(PageStatus.FinishSearch, "Consulta executada correctament");
   }

   /** Inicializa el componente. */
   init() {
      this.status = PageStatus.Init;
      this.hql = HQL.newObject();
      this.hql.reset();
   }

   /** Envía la consulta/ejecución de HQL. */
   sendSHQL(esHQL: boolean, execute: boolean) {
      // Evitamos iniciar una nueva búsqueda cuando la anterior aún está en curso (p. ej., double click)
      if (this.status === PageStatus.Searching) { return; }
      this.status = PageStatus.Searching;
      //this._developerService.sendHQLTest()
      this.developerService.sendSHQL(esHQL, this.hql, execute)
          .subscribe(
            result => { 
                this.hql = result; 
                this.status = PageStatus.FinishSearch; 
            },
            error  => { 
                this.status = PageStatus.Error; 
                this.messageService.sendMessage(new BitMessage("Error", error));
            }
          );
   }

   /** Limpia la información de consulta/ejecución. */
   resetForm(): void {
      this.init();
   }
   
   /** Flag: la página está realizando la búsqueda. */
   get searchInitiated() { return this.status === PageStatus.Init; }

   /** Flag: la página está realizando la búsqueda. */
   get searching() { return this.status === PageStatus.Searching; }

   /** Flag: la página ha finalizado la última búsqueda. */
   get searchFinished() { return this.status === PageStatus.FinishSearch; }

   /** Información de debug. */
   get diagnostic() { return JSON.stringify(this.hql); }

}