import {Component,
        Input, 
        Output,
        EventEmitter}               from '@angular/core';
import {FormBuilder, 
        FormGroup, 
        Validators}                 from '@angular/forms';
import {BaseFilter}                 from '../../base/index';
import {BaseFilterComponent}        from '../../base/index';
import {LogFilter}                  from '../shared/data/log.filter'; 
import {CustomValidators,
        BitMessage}                 from '../../shared/index';
import {MessageService}             from '../../shared/service/message.service';
import {SessionSharedService}       from '../../shared/service/session-shared.service';

@Component({

    selector: 'log-list-filter',
    template: "\n      <div class=\"panel panel-filtro\" [hidden]=\"!displayFilter\">\n          <div class=\"panel-heading\">\n              <i></i>&nbsp;&nbsp;&nbsp;Filtre de cerca:\n          </div>\n          <form role=\"form\" [formGroup]=\"myForm\" (submit)=\"submit(myForm.value)\">\n              <div class=\"panel-body\">\n                  <div class=\"row\">\n                      <div class=\"col-xs-2\">\n                          <bit-input [(ngModel)]=\"filter.fecha\" nombre=\"fecha\" [control]=\"myForm.controls.fecha\" formControlName=\"fecha\" tipo=\"date\">&nbsp;&nbsp;Data</bit-input>\n                      </div>\n                      <div class=\"col-xs-2\">\n                          <bit-input [(ngModel)]=\"filter.desde\" nombre=\"desde\" [control]=\"myForm.controls.desde\" formControlName=\"desde\" tipo=\"time\">&nbsp;&nbsp;Des de</bit-input>\n                      </div>\n                      <div class=\"col-xs-2\">\n                          <bit-input [(ngModel)]=\"filter.hasta\" nombre=\"hasta\" [control]=\"myForm.controls.hasta\" formControlName=\"hasta\" tipo=\"time\">&nbsp;&nbsp;Fins a</bit-input>\n                      </div>\n                      <div class=\"col-xs-2\">\n                          <bit-input [(ngModel)]=\"filter.login\" nombre=\"login\" [control]=\"myForm.controls.login\" formControlName=\"login\" tipo=\"text\" >&nbsp;&nbsp;Login</bit-input>\n                      </div>\n                      <div class=\"col-xs-2\">\n                          <bit-select domain=\"tipoLog\" nombre=\"tipolog\" [filter]=\"false\" [(ngModel)]=\"filter.tipoLog\" [ngModelOptions]=\"{standalone: true}\">&nbsp;&nbsp;Tipus d'operació</bit-select>\n                      </div>\n                      <div class=\"col-xs-2\">\n                          <bit-input [(ngModel)]=\"filter.mostrarErrores\" nombre=\"mostrarErrores\" [ngModelOptions]=\"{standalone: true}\" tipo=\"checkbox\">Només errors</bit-input>\n                      </div>\n                  </div>\n              </div>\n              <div class=\"panel-footer text-center\">\n                  <div class=\"btn-group\" role=\"group\">\n                      <button type=\"reset\" (click)=\"resetFilter()\" class=\"btn btn-default\" >Neteja&nbsp;&nbsp;<span class=\"glyphicon glyphicon-erase\"></span></button>\n                  </div>\n                  <div class=\"btn-group\" role=\"group\">\n                      <button type=\"submit\" class=\"btn btn-success\">Cerca&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n                  </div>\n              </div>\n          </form>\n      </div>\n    "
})
export class LogListFilterComponent extends BaseFilterComponent {    
    filter: LogFilter;          // contiene el filtro de búsqueda. Será accedido directamente desde el padre
    
    constructor(
        private formBuilder: FormBuilder, 
        private messageService: MessageService,
        private sessionShared: SessionSharedService
    ) {
        super();
        //gestión del filtro. TO-DO: ¿A BaseListFilter?
        this.filter = this.sessionShared.get("LOG_FILTER") || this.createNewFilter();
        this.sessionShared.set("LOG_FILTER", this.filter);
        //siempre que iniciamos el componente restauramos la página y el número de elementos por página. TO-DO: ¿A BaseListFilter?
        this.filter.pagina = BaseFilter.PAGE;
        this.filter.resultados = BaseFilter.RESULTADOS_PAGE;
        //construimos el form         
        this.myForm = formBuilder.group({
            'fecha': [this.filter.fecha, [Validators.required, CustomValidators.dataValidator]],
            'desde': [this.filter.desde, [Validators.required]],//CustomValidators.timeValidator
            'hasta': [this.filter.hasta, [Validators.required]], //CustomValidators.timeValidator
            'login': [this.filter.login, [Validators.required]]
        });
    }

    
    /** Crea un nuevo filtro para realizar la búsqueda */
    createNewFilter(): LogFilter {
        return LogFilter.newObject(); 
    }

}
