"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var router_1 = require("@angular/router");
var ayuda_service_1 = require("../service/ayuda.service");
var session_shared_service_1 = require("../service/session-shared.service");
var noop = function () { };
var ɵ0 = noop;
exports.ɵ0 = ɵ0;
exports.CUSTOM_SELECT_MULTIPLE_CONTROL_VALUE_ACCESSOR = {
    provide: forms_1.NG_VALUE_ACCESSOR,
    useExisting: core_1.forwardRef(function () { return BitSelectMultipleComponent; }),
    multi: true
};
/**
* Clase que utiliza un custom componente para select múltiple de elementos
* Utiliza la interfaz ControlValueAccessor
*    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [(ngModel)]="filter.tipoLog" [ngModelOptions]="{standalone: true}">&nbsp;&nbsp;Tipus d'operació</bit-select>
*
* @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
* @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
* @input id: identificador del componente select
**/
var BitSelectMultipleComponent = /** @class */ (function () {
    function BitSelectMultipleComponent(router, sessionShared, ayudaService) {
        this.router = router;
        this.sessionShared = sessionShared;
        this.ayudaService = ayudaService;
        this.lectura = false;
        this.readOnly = false;
        this.emptyText = 'Cap';
        this.hideLabel = false;
        this.maxSelectedLabels = 3;
        this.showSeparateSelectedLabels = false;
        // Si se pueden seleccionar muchos elementos, que el label de los elementos seleccionados no
        // aparezca dentro del select, y hacerlo como una lista fuera del select.
        this.listaOpciones = [];
        this.forceObligatorio = false;
        this.onChange = new core_1.EventEmitter();
        this.innerValue = '';
        this.onTouchedCallback = noop;
        this.onChangeCallback = noop;
    }
    BitSelectMultipleComponent.prototype.ngOnInit = function () {
        var _this = this;
        //console.log("Vamos a mapear los datos precargados");
        if (this.data == null && this.domain != null) {
            //esta manera retornaría los datos alojados en el snapshot pero no tendríamos refresco en el caso de producirse
            //this.tiposLog = this.getTiposLogFromDomain(this.route.snapshot.data[TipoLog.DOMAIN_TIPO_LOG]);//this.route.data.pluck(TipoLog.DOMAIN_TIPO_LOG);
            //esta manera nos permite subscribirnos a los datos de data con lo que si hay refresco nos enteramos
            this.router.data.subscribe(function (result) {
                var dominios = result['dominios'];
                var domainTipo = dominios[_this.domain];
                if (domainTipo != null) {
                    domainTipo.subscribe(function (result) {
                        console.log(result);
                        _this.sessionShared.set(_this.domain, result.slice()); // almacenamos en sesión una copia para evitar transmitir cambios
                        _this.listaOpciones = result;
                        _this.postRetrieveData();
                    }, function (error) { _this.listaOpciones = [{ value: null, label: 'Error carrega dominis' }]; });
                }
                else {
                    console.log("No hay datos para el dominio", _this.domain);
                    _this.listaOpciones = [{ value: null, label: 'Error carrega dominis' }];
                }
            });
        }
        else if (this.data) {
            // incluso si la lista de valores ha sido proporcionada,
            // hay que añadir algunos comportamientos posteriores
            this.listaOpciones = this.data.slice();
            this.postRetrieveData();
        }
        //console.log("Componente inicializado");
    };
    BitSelectMultipleComponent.prototype.ngOnChanges = function (changes) {
        for (var propName in changes) {
            var changedProp = changes[propName];
            if (propName === 'data') {
                this.listaOpciones = changedProp.currentValue ? changedProp.currentValue.slice() : [];
                this.postRetrieveData();
            }
            else if (propName === 'dominio') {
                this.domain = changedProp.currentValue;
                // TODO: recargar dominio por si es distinto?
            }
        }
    };
    // custom processing after retrieving data array from service
    // custom processing after retrieving data array from service
    BitSelectMultipleComponent.prototype.postRetrieveData = 
    // custom processing after retrieving data array from service
    function () {
    };
    Object.defineProperty(BitSelectMultipleComponent.prototype, "value", {
        //get accessor
        get: 
        //get accessor
        function () {
            return this.innerValue;
        },
        //set accessor including call the onchange callback
        set: 
        //set accessor including call the onchange callback
        function (v) {
            if (v !== this.innerValue) {
                this.innerValue = v;
            }
            //this.onChangeCallback(v);
        },
        enumerable: true,
        configurable: true
    });
    ;
    Object.defineProperty(BitSelectMultipleComponent.prototype, "label", {
        get: function () {
            var val = this.value;
            var labels = this.listaOpciones && this.listaOpciones
                .filter(function (d) { return val && val.indexOf(d.value) > -1; })
                .map(function (d) { return d.label; });
            return labels ? labels.join(", ") : null;
        },
        enumerable: true,
        configurable: true
    });
    BitSelectMultipleComponent.prototype.changed = function (event) {
        this.onTouchedCallback();
        this.onChangeCallback(this.innerValue); //TODO: probar que esto es así
        this.onChange.emit(event);
    };
    BitSelectMultipleComponent.prototype.onBlur = function () {
        this.onTouchedCallback();
    };
    BitSelectMultipleComponent.prototype.onFocus = function () {
        this.onTouchedCallback();
        // this.onChangeCallback(this.innerValue);
    };
    BitSelectMultipleComponent.prototype.writeValue = function (value) {
        if (value !== this.innerValue) {
            this.innerValue = value;
        }
    };
    BitSelectMultipleComponent.prototype.registerOnChange = function (fn) {
        this.onChangeCallback = fn;
    };
    BitSelectMultipleComponent.prototype.registerOnTouched = function (fn) {
        this.onTouchedCallback = fn;
    };
    Object.defineProperty(BitSelectMultipleComponent.prototype, "obligatorio", {
        // decidimos marcar el campo como obligatorio si se ha indicado a la fuerza (por parámetro)
        // o si el control de formulario asociado está saltando por ser obligatorio y no haberse rellenado
        get: 
        // decidimos marcar el campo como obligatorio si se ha indicado a la fuerza (por parámetro)
        // o si el control de formulario asociado está saltando por ser obligatorio y no haberse rellenado
        function () {
            return this.forceObligatorio || (this.control && this.control.errors && this.control.errors['required']);
        },
        enumerable: true,
        configurable: true
    });
    BitSelectMultipleComponent.prototype.showAyuda = function () {
        this.ayudaService.mostrarAyuda(this.ayuda);
    };
    BitSelectMultipleComponent.prototype.labelSelectedItem = function (id) {
        return this.listaOpciones.find(function (c) { return c.value == id; }).label;
    };
    BitSelectMultipleComponent.prototype.deleteSelectedItem = function (event, item, tipoCategoria) {
        event.preventDefault();
        var index = this.value.indexOf(item);
        this.value.splice(index, 1);
        // se clona el array. Si no, el texto "{0} elementos seleccionados" del select de Prime no se actualiza.
        this.value = this.value.slice(0);
        this.changed(event);
    };
    BitSelectMultipleComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'bit-select-multiple',
                    template: "\n            <div class=\"row separador\" *ngIf=\"showSeparateSelectedLabels; else normalBitSelectMultiple\">\n                <div class=\"col-sm-3\">\n                    <ng-container *ngTemplateOutlet=\"normalBitSelectMultiple\"></ng-container>\n                </div>\n                <div class=\"col-sm-9\"><!-- elementos seleccionados -->\n                    <label>&nbsp;</label>\n                    <div class=\"multiselect-labels\">\n                        <div class=\"label label-primary multiselect-labels-lg\" *ngFor=\"let item of value\">\n                        <span>{{labelSelectedItem(item)}}</span>\n                        <a (click)=\"deleteSelectedItem($event, item , 'categoriaPrincipal')\" title=\"Esborra categoria\"> <i class=\"fa fa-times\"></i></a>\n                        </div>\n                    </div>\n                </div>\n            </div>\n            <ng-template #normalBitSelectMultiple>\n            <label *ngIf=\"!hideLabel\"><ng-content></ng-content>&nbsp;<span *ngIf=\"obligatorio\" class=\"fa fa-asterisk\"></span>\n            &nbsp;&nbsp;\n                <i *ngIf=\"ayuda\" (click)=\"showAyuda()\" class=\"btn-ayuda fa fa-question\"></i>\n            </label>\n            <p *ngIf=\"lectura || readOnly\" class=\"lectura\">{{label}}</p>\n            <div *ngIf=\"!readOnly\">\n                <p-multiSelect *ngIf=\"!lectura\" [options]=\"listaOpciones\" [defaultLabel]=\"emptyText\" [(ngModel)]=\"value\" id=\"{{id}}\" \n                    (onFocus)=\"onFocus()\" (onBlur)=\"onBlur()\" (onChange)=\"changed(event)\" [maxSelectedLabels]=\"maxSelectedLabels\"\n                    selectedItemsLabel=\"{0} elements seleccionats\">\n                </p-multiSelect>\n            <control-messages *ngIf=\"control!=null\" [control]=\"control\" [field]=\"id\"></control-messages>\n            </div>\n            </ng-template>\n",
                    providers: [exports.CUSTOM_SELECT_MULTIPLE_CONTROL_VALUE_ACCESSOR]
                },] },
    ];
    /** @nocollapse */
    BitSelectMultipleComponent.ctorParameters = function () { return [
        { type: router_1.ActivatedRoute, },
        { type: session_shared_service_1.SessionSharedService, },
        { type: ayuda_service_1.AyudaService, },
    ]; };
    BitSelectMultipleComponent.propDecorators = {
        "control": [{ type: core_1.Input },],
        "id": [{ type: core_1.Input },],
        "ayuda": [{ type: core_1.Input },],
        "lectura": [{ type: core_1.Input },],
        "readOnly": [{ type: core_1.Input },],
        "emptyText": [{ type: core_1.Input },],
        "hideLabel": [{ type: core_1.Input },],
        "maxSelectedLabels": [{ type: core_1.Input },],
        "showSeparateSelectedLabels": [{ type: core_1.Input },],
        "data": [{ type: core_1.Input },],
        "domain": [{ type: core_1.Input },],
        "forceObligatorio": [{ type: core_1.Input },],
        "onChange": [{ type: core_1.Output },],
    };
    return BitSelectMultipleComponent;
}());
exports.BitSelectMultipleComponent = BitSelectMultipleComponent;
//# sourceMappingURL=bit-select-multiple.component.js.map