import {EventEmitter,
        Output,
        Input,
        AfterContentInit}   from '@angular/core';
import {FormGroup}          from '@angular/forms';

import {BaseFilter}         from '../shared/base.filter';
import {CustomValidators}   from '../../shared/service/custom-validators.service';

export abstract class BaseFilterComponent{
    filter: BaseFilter;
    myForm: FormGroup;                  // form de búsqueda
    @Input() displayFilter: boolean;    // nos indica si debemos o no mostrarnos    
    @Output() onSearch = new EventEmitter<BaseFilter>(); // se activará cuando pulsen en buscar
    @Output() onReset = new EventEmitter<BaseFilter>();

    constructor(){
    }

    abstract createNewFilter(): BaseFilter;

    submit(value?: string): void {
        if (!this.myForm.valid) { //this.myForm.dirty puede que no lo hayamos tocado
            let errores = CustomValidators.validateForm(this.myForm);
            alert(`El filtre de cerca conté les següents errades: ${errores.reduce((v1, v2) => v1 + '\n' + v2, '')}`);
        }else{
            this.onSearch.emit(this.filter); //comunicamos hacia arriba que debe realizarse la búsqueda
        }
    }

    resetFilter(): boolean {
        this.filter.reset();
        this.onReset.emit(this.filter);
        this.postResetFilter();
        return false;
    }

    postResetFilter() {}

    get diagnostic() { return JSON.stringify(this.filter); }
}