import {Component,
        Input, 
        Output,
        EventEmitter}               from '@angular/core';
import {FormBuilder, 
        FormGroup, 
        Validators}                 from '@angular/forms';
import {BaseFilter}                 from '../../base/index';
import {BaseFilterComponent}        from '../../base/index';
import {LogFilter}                  from '../shared/data/log.filter'; 
import {CustomValidators,
        BitMessage}                 from '../../shared/index';
import {MessageService}             from '../../shared/service/message.service';
import {SessionSharedService}       from '../../shared/service/session-shared.service';

@Component({

    selector: 'log-list-filter',
    templateUrl: './log-list-filter.component.html'
})
export class LogListFilterComponent extends BaseFilterComponent {    
    filter: LogFilter;          // contiene el filtro de búsqueda. Será accedido directamente desde el padre
    
    constructor(
        private formBuilder: FormBuilder, 
        private messageService: MessageService,
        private sessionShared: SessionSharedService
    ) {
        super();
        //gestión del filtro. TO-DO: ¿A BaseListFilter?
        this.filter = this.sessionShared.get("LOG_FILTER") || this.createNewFilter();
        this.sessionShared.set("LOG_FILTER", this.filter);
        //siempre que iniciamos el componente restauramos la página y el número de elementos por página. TO-DO: ¿A BaseListFilter?
        this.filter.pagina = BaseFilter.PAGE;
        this.filter.resultados = BaseFilter.RESULTADOS_PAGE;
        //construimos el form         
        this.myForm = formBuilder.group({
            'fecha': [this.filter.fecha, [Validators.required, CustomValidators.dataValidator]],
            'desde': [this.filter.desde, [Validators.required]],//CustomValidators.timeValidator
            'hasta': [this.filter.hasta, [Validators.required]], //CustomValidators.timeValidator
            'login': [this.filter.login, [Validators.required]]
        });
    }

    
    /** Crea un nuevo filtro para realizar la búsqueda */
    createNewFilter(): LogFilter {
        return LogFilter.newObject(); 
    }

}
