import { Injectable }         from '@angular/core';
import { Observable }         from 'rxjs'; 

import { HttpUtilsService }   from '../../../shared/service/http-utils.service';
import { MessageService }     from '../../../shared/service/message.service';
import { BaseCRUDService }    from '../../../base/shared/base.service';
import { HQL }                from '../data/hql';
import { Log }                from '../data/log';
import { LogExceptionFilter } from '../data/log-exception.filter';
import { LogFilter }          from '../data/log.filter';

@Injectable()
export class DeveloperService extends BaseCRUDService
{
   protected baseUrl = 'desarrollo';
   private hqlUrl = this.baseUrl + '/hql';
   private sqlUrl = this.baseUrl + '/sql';
   private hqlExecuteUrl = this.baseUrl + '/hql/execute';
   private sqlExecuteUrl = this.baseUrl + '/sql/execute';  // TODO: no implementado en servidor
   private countAllExceptionsByFilterUrl = this.baseUrl + '/exceptions/count';
   private getAllExceptionsByFilterUrl = this.baseUrl + '/exceptions/filter';

   constructor(
        protected messageService: MessageService,
        protected http: HttpUtilsService,
    ) {
      super(messageService, http);
   }

   sendSHQL(esHQL: boolean, hqlRequest, execute): Observable<any> {
      let url;
      if (esHQL) { url = (execute) ? this.hqlExecuteUrl : this.hqlUrl; }
      else       { url = (execute) ? this.sqlExecuteUrl : this.sqlUrl; }
      return this.http.getHttpPost(url, hqlRequest);
   }

   getAllByFilter<T>(logFilter: LogExceptionFilter): Observable<T> {
      return this.http.getHttpPost(this.getAllExceptionsByFilterUrl, logFilter);
   }


   countAllByFilter(logFilter: LogExceptionFilter): Observable<number> {
      return this.http.getHttpPost(this.countAllExceptionsByFilterUrl, logFilter);
   }

}